@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'date'
 
 module Mocha
@@ -6,21 +8,33 @@ module Mocha
       def mocha_inspect
         address = __id__ * 2
         address += 0x100000000 if address < 0
-        inspect =~ /#</ ? "#<#{self.class}:0x#{Kernel.format('%x', address)}>" : inspect
+        inspect =~ /#</ ? "#<#{self.class}:0x#{Kernel.format('%<address>x', address: address)}>" : inspect
       end
     end
 
     module ArrayMethods
-      def mocha_inspect(wrapped = true)
+      def mocha_inspect(wrapped: true)
         unwrapped = collect(&:mocha_inspect).join(', ')
         wrapped ? "[#{unwrapped}]" : unwrapped
       end
     end
 
     module HashMethods
-      def mocha_inspect(wrapped = true)
-        unwrapped = collect { |key, value| "#{key.mocha_inspect} => #{value.mocha_inspect}" }.join(', ')
-        wrapped ? "{#{unwrapped}}" : unwrapped
+      def mocha_inspect
+        unwrapped = collect do |key, value|
+          case key
+          when Symbol
+            "#{key}: #{value.mocha_inspect}"
+          else
+            "#{key.mocha_inspect} => #{value.mocha_inspect}"
+          end
+        end.join(', ')
+
+        if Hash.ruby2_keywords_hash?(self)
+          empty? ? '**{}' : unwrapped
+        else
+          "{#{unwrapped}}"
+        end
       end
     end
 
