@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../acceptance_test_helper', __FILE__)
 
 class Bug18914Test < Mocha::TestCase
-  include AcceptanceTest
+  include AcceptanceTestHelper
 
   def setup
     setup_acceptance_test
@@ -12,7 +14,7 @@ class Bug18914Test < Mocha::TestCase
   end
 
   class AlwaysEql
-    def my_method
+    def my_method # rubocop:disable Naming/PredicateMethod
       true
     end
 
