@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'execution_point'
 
 class MochaTestResultTest < Mocha::TestCase
-  include AcceptanceTest
+  include AcceptanceTestHelper
 
   def setup
     setup_acceptance_test
@@ -21,6 +23,23 @@ class MochaTestResultTest < Mocha::TestCase
     assert_equal 1, test_result.assertion_count
   end
 
+  def test_should_not_include_unexpected_invocation_failure_in_assertion_count
+    test_result = run_as_test do
+      object = mock
+      object.message
+    end
+    assert_equal 0, test_result.assertion_count
+  end
+
+  def test_should_include_never_expected_invocation_failure_in_assertion_count
+    test_result = run_as_test do
+      object = mock
+      object.expects(:message).never
+      object.message
+    end
+    assert_equal 1, test_result.assertion_count
+  end
+
   def test_should_include_assertions_in_assertion_count
     test_result = run_as_test do
       assert true
@@ -45,7 +64,7 @@ class MochaTestResultTest < Mocha::TestCase
     assert_equal 1, test_result.failure_count
   end
 
-  def test_should_include_unexpected_verification_failure_in_failure_count
+  def test_should_include_unexpected_invocation_failure_in_failure_count
     test_result = run_as_test do
       object = mock
       object.message
