@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../acceptance_test_helper', __FILE__)
 
 class MockTest < Mocha::TestCase
-  include AcceptanceTest
+  include AcceptanceTestHelper
   include Mocha
 
   def setup
