@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../acceptance_test_helper', __FILE__)
 
 class StubMethodDefinedOnModuleAndAliasedTest < Mocha::TestCase
-  include AcceptanceTest
+  include AcceptanceTestHelper
 
   def setup
     setup_acceptance_test
@@ -20,6 +22,7 @@ class StubMethodDefinedOnModuleAndAliasedTest < Mocha::TestCase
 
     klass = Class.new do
       extend mod
+
       class << self
         alias_method :aliased_module_instance_method, :module_instance_method
       end
