@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 
 class StubbingMethodAcceptingBlockParameterTest < Mocha::TestCase
-  include AcceptanceTest
+  include AcceptanceTestHelper
 
   def setup
     setup_acceptance_test
@@ -22,7 +23,7 @@ class StubbingMethodAcceptingBlockParameterTest < Mocha::TestCase
       klass.stubs(:my_class_method)
     end
     assert_passed(test_result)
-    assert_equal :return_value, (klass.my_class_method { :return_value })
+    assert_equal(:return_value, klass.my_class_method { :return_value })
   end
 
   def test_stubbing_instance_method_accepting_block_parameter_should_restore_original_method
@@ -35,7 +36,7 @@ class StubbingMethodAcceptingBlockParameterTest < Mocha::TestCase
       instance.stubs(:my_instance_method)
     end
     assert_passed(test_result)
-    assert_equal :return_value, (instance.my_instance_method { :return_value })
+    assert_equal(:return_value, instance.my_instance_method { :return_value })
   end
 
   def test_stubbing_any_instance_method_accepting_block_parameter_should_restore_original_method
@@ -48,6 +49,6 @@ class StubbingMethodAcceptingBlockParameterTest < Mocha::TestCase
       klass.any_instance.stubs(:my_instance_method)
     end
     assert_passed(test_result)
-    assert_equal :return_value, (klass.new.my_instance_method { :return_value })
+    assert_equal(:return_value, klass.new.my_instance_method { :return_value })
   end
 end
