@@ -1,8 +1,11 @@
+# frozen_string_literal: true
+
 require 'forwardable'
 
 class MinitestResult
   class Failure
     extend Forwardable
+
     def_delegators :@failure, :message, :backtrace
 
     def initialize(failure)
@@ -14,6 +17,8 @@ class MinitestResult
     end
   end
 
+  attr_accessor :last_deprecation_warning
+
   def initialize(tests)
     @tests = tests
   end
