@@ -1,17 +1,24 @@
-require 'assertions'
+# frozen_string_literal: true
 
-require 'mocha/detection/mini_test'
+require 'assertions'
+require 'deprecation_capture'
+
+require 'mocha/detection/minitest'
 
 module TestRunner
   def run_as_test(&block)
     run_as_tests(test_me: block)
   end
 
-  # rubocop:disable Metrics/AbcSize
+  # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
   def run_as_tests(methods = {})
     base_class = Mocha::TestCase
     test_class = Class.new(base_class) do
-      include Assertions
+      def self.name;
+        'FakeTest'
+      end
+
+      include Assertions, DeprecationCapture
 
       methods.each do |(method_name, proc)|
         define_method(method_name, proc)
@@ -20,21 +27,15 @@ module TestRunner
 
     tests = methods.keys.select { |m| m.to_s[/^test/] }.map { |m| test_class.new(m) }
 
-    if Mocha::Detection::MiniTest.testcase && (ENV['MOCHA_RUN_INTEGRATION_TESTS'] != 'test-unit')
-      minitest_version = Gem::Version.new(Mocha::Detection::MiniTest.version)
-      if Gem::Requirement.new('>= 5.0.0').satisfied_by?(minitest_version)
-        require File.expand_path('../minitest_result', __FILE__)
-        tests.each(&:run)
-        Minitest::Runnable.runnables.delete(test_class)
-        test_result = MinitestResult.new(tests)
-      elsif Gem::Requirement.new('> 0.0.0', '< 5.0.0').satisfied_by?(minitest_version)
-        require File.expand_path('../mini_test_result', __FILE__)
-        runner = MiniTest::Unit.new
-        tests.each do |test|
-          test.run(runner)
-        end
-        test_result = MiniTestResult.new(runner, tests)
-      end
+    if Mocha::Detection::Minitest.testcase && (ENV['MOCHA_RUN_INTEGRATION_TESTS'] != 'test-unit')
+      minitest_version = Gem::Version.new(Mocha::Detection::Minitest.version)
+      minitest_version_supported = Gem::Requirement.new('>= 5.0.0').satisfied_by?(minitest_version)
+      raise "Minitest v#{minitest_version} not supported" unless minitest_version_supported
+
+      require File.expand_path('../minitest_result', __FILE__)
+      tests.each(&:run)
+      Minitest::Runnable.runnables.delete(test_class)
+      test_result = MinitestResult.new(tests)
     else
       require File.expand_path('../test_unit_result', __FILE__)
       test_result = TestUnitResult.build_test_result
@@ -43,9 +44,9 @@ module TestRunner
       end
     end
 
-    test_result
+    test_result.tap { |r| r.last_deprecation_warning = tests.flat_map(&:deprecation_warnings).last }
   end
-  # rubocop:enable Metrics/AbcSize
+  # rubocop:enable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
 
   def assert_passed(test_result)
     flunk "Test errored unexpectedly with message: #{test_result.errors.map(&:exception)}" if test_result.error_count > 0
