@@ -1,7 +1,11 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../test_helper', __FILE__)
 
 require 'mocha/central'
+require 'mocha/mockery'
 require 'mocha/mock'
+require 'simple_counter'
 
 class CentralTest < Mocha::TestCase
   include Mocha
@@ -93,6 +97,7 @@ class CentralTest < Mocha::TestCase
   private
 
   def build_mock
-    Mock.new(nil)
+    counter = SimpleCounter.new
+    Mock.new(Mockery.new(counter), counter)
   end
 end
