@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/method_matcher'
 
 class MethodMatcherTest < Mocha::TestCase
-
   include Mocha
 
   def test_should_match_if_actual_method_name_is_same_as_expected_method_name
@@ -22,7 +23,6 @@ class MethodMatcherTest < Mocha::TestCase
 
   def test_should_describe_what_method_is_expected
     method_matcher = MethodMatcher.new(:method_name)
-    assert_equal "method_name", method_matcher.mocha_inspect
+    assert_equal 'method_name', method_matcher.mocha_inspect
   end
-
 end
