@@ -1,13 +1,16 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/object_methods'
 require 'mocha/mockery'
 require 'mocha/mock'
 require 'mocha/expectation_error_factory'
-require 'mocha/names'
+require 'mocha/impersonating_name'
+require 'simple_counter'
 
 class ObjectMethodsTest < Mocha::TestCase
   def setup
-    Mocha::Mockery.setup
+    Mocha::Mockery.setup(SimpleCounter.new)
     @object = Object.new.extend(Mocha::ObjectMethods)
   end
 
@@ -24,7 +27,7 @@ class ObjectMethodsTest < Mocha::TestCase
   end
 
   def test_should_not_build_mocha_if_instantiate_is_false
-    assert_nil @object.mocha(false)
+    assert_nil @object.mocha(instantiate: false)
   end
 
   def test_should_reuse_existing_mocha
@@ -35,7 +38,7 @@ class ObjectMethodsTest < Mocha::TestCase
 
   def test_should_reuse_existing_mocha_even_if_instantiate_is_false
     mocha1 = @object.mocha
-    mocha2 = @object.mocha(false)
+    mocha2 = @object.mocha(instantiate: false)
     assert_equal mocha1, mocha2
   end
 
