@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../../test_helper', __FILE__)
 
 require 'mocha/parameter_matchers/equals'
 require 'mocha/inspect'
 
 class EqualsTest < Mocha::TestCase
-  include Mocha::ParameterMatchers
+  include Mocha::ParameterMatchers::Methods
 
   def test_should_match_object_that_equals_value
     matcher = equals('x')
