@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../../test_helper', __FILE__)
 
 require 'mocha/parameter_matchers/has_key'
@@ -5,7 +7,7 @@ require 'mocha/parameter_matchers/instance_methods'
 require 'mocha/inspect'
 
 class HasKeyTest < Mocha::TestCase
-  include Mocha::ParameterMatchers
+  include Mocha::ParameterMatchers::Methods
 
   def test_should_match_hash_including_specified_key
     matcher = has_key(:key_1)
