@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../../test_helper', __FILE__)
 
 require 'mocha/parameter_matchers/yaml_equivalent'
 require 'mocha/inspect'
 
 class YamlEquivalentTest < Mocha::TestCase
-  include Mocha::ParameterMatchers
+  include Mocha::ParameterMatchers::Methods
 
   def test_should_match_parameter_matching_yaml_representation_of_object
     matcher = yaml_equivalent([1, 2, 3])
